import type { DiagnosticCode } from '@astrojs/compiler/shared/diagnostics.js';
import { AstroErrorCodes } from './codes.js';
interface ErrorProperties {
    errorCode: AstroErrorCodes | DiagnosticCode;
    name?: string;
    message?: string;
    location?: ErrorLocation;
    hint?: string;
    stack?: string;
    frame?: string;
}
export interface ErrorLocation {
    file?: string;
    line?: number;
    column?: number;
}
declare type ErrorTypes = 'CSSError' | 'CompilerError' | 'RuntimeError' | 'MarkdownError' | 'AstroAggregateError';
export declare class AstroError extends Error {
    errorCode: AstroErrorCodes | DiagnosticCode;
    loc: ErrorLocation | undefined;
    hint: string | undefined;
    frame: string | undefined;
    type: ErrorTypes | undefined;
    constructor(props: ErrorProperties, ...params: any);
    setErrorCode(errorCode: AstroErrorCodes | DiagnosticCode): void;
    setLocation(location: ErrorLocation): void;
    setName(name: string): void;
    setMessage(message: string): void;
    setHint(hint: string): void;
    setFrame(source: string, location: ErrorLocation): void;
}
export declare class CSSError extends AstroError {
    type: ErrorTypes;
    static is(err: Error | unknown): boolean;
}
export declare class CompilerError extends AstroError {
    type: ErrorTypes;
    constructor(props: ErrorProperties & {
        errorCode: DiagnosticCode | AstroErrorCodes.UnknownCompilerError;
    }, ...params: any);
    static is(err: Error | unknown): boolean;
}
export declare class RuntimeError extends AstroError {
    type: ErrorTypes;
    static is(err: Error | unknown): boolean;
}
export declare class MarkdownError extends AstroError {
    type: ErrorTypes;
    static is(err: Error | unknown): boolean;
}
export declare class AggregateError extends AstroError {
    type: ErrorTypes;
    errors: AstroError[];
    constructor(props: ErrorProperties & {
        errors: AstroError[];
    }, ...params: any);
    static is(err: Error | unknown): boolean;
}
/**
 * Generic object representing an error with all possible data
 * Compatible with both Astro's and Vite's errors
 */
export interface ErrorWithMetadata {
    [name: string]: any;
    type?: ErrorTypes;
    message: string;
    stack: string;
    code?: number;
    hint?: string;
    id?: string;
    frame?: string;
    plugin?: string;
    pluginCode?: string;
    loc?: {
        file?: string;
        line?: number;
        column?: number;
    };
}
export {};
